==> node-nouislider_15.5.1+ds.orig.tar.xz: noUiSlider-15.5.1/documentation/examples.php <==
<?php
	$title = "noUiSlider - Examples and hints";
	$description = "noUiSlider has a selection of examples you can use to implement a slider easily. Take a look!";
    $canonical = "nouislider/examples/"
?>

<section>
	<ul>
		<li><a href="#section-colorpicker">Color picker</a></li>
		<li><a href="#section-styling">Styling</a></li>
		<li><a href="#section-dates">Using dates</a></li>
		<li><a href="#section-merging-tooltips">Merging overlapping tooltips</a></li>
		<li><a href="#section-html5">Working with HTML5 input types</a></li>
		<li><a href="#section-non-linear">Using non linear ranges</a></li>
		<li><a href="#section-lock">Locking two sliders together</a></li>
		<li><a href="#section-click-pips">Moving the slider by clicking pips</a></li>
		<li><a href="#section-hiding-tooltips">Only showing tooltips when sliding handles</a></li>
		<li><a href="#section-colored-connect">Colored connect elements</a></li>
		<li><a href="#section-steps-api">Changing the slider value by keypress</a></li>
		<li><a href="#section-skipping">Skipping values on a slider</a></li>
		<li><a href="#section-huge-numbers">Working with huge numbers</a></li>
		<li><a href="#section-toggle">Create a toggle</a></li>
		<li><a href="#section-soft-limits">Block the edges of a slider</a></li>
		<li><a href="#section-from-center">Connect to the center of a slider</a></li>
	</ul>
</section>

<section>
    <div class="notice">Can't find something? See the full <a href="/nouislider/reference/">options reference</a>.</div>
</section>

<?php include 'examples-content/colorpicker.php'; ?>
<?php include 'examples-content/styling.php'; ?>
<?php include 'examples-content/dates.php'; ?>
<?php include 'examples-content/merging-tooltips.php'; ?>
<?php include 'examples-content/html5.php'; ?>
<?php include 'examples-content/non-linear.php'; ?>
<?php include 'examples-content/lock.php'; ?>
<?php include 'examples-content/click-pips.php'; ?>
<?php include 'examples-content/hiding-tooltips.php'; ?>
<?php include 'examples-content/colored-connect.php'; ?>
<?php include 'examples-content/steps-api.php'; ?>
<?php include 'examples-content/skipping.php'; ?>
<?php include 'examples-content/huge-numbers.php'; ?>
<?php include 'examples-content/toggle.php'; ?>
<?php include 'examples-content/soft-limits.php'; ?>
<?php include 'examples-content/from-center.php'; ?>

==> node-nouislider_15.8.1+ds.orig.tar.xz: noUiSlider-15.8.1/documentation/examples.php <==
<?php
	$title = "noUiSlider - Examples and hints";
	$description = "noUiSlider has a selection of examples you can use to implement a slider easily. Take a look!";
    $canonical = "nouislider/examples/"
?>

<section>
	<ul>
		<li><a href="#section-values">Using an array of values</a></li>
		<li><a href="#section-formatting">Number formatting</a></li>
		<li><a href="#section-colorpicker">Color picker</a></li>
		<li><a href="#section-styling">Styling</a></li>
		<li><a href="#section-pips">Interacting with Pips</a></li>
		<li><a href="#section-dates">Using dates</a></li>
		<li><a href="#section-merging-tooltips">Merging overlapping tooltips</a></li>
		<li><a href="#section-html5">Working with HTML5 input types</a></li>
		<li><a href="#section-non-linear">Using non linear ranges</a></li>
		<li><a href="#section-lock">Locking two sliders together</a></li>
		<li><a href="#section-click-pips">Moving the slider by clicking pips</a></li>
		<li><a href="#section-hiding-tooltips">Only showing tooltips when sliding handles</a></li>
		<li><a href="#section-colored-connect">Colored connect elements</a></li>
		<li><a href="#section-steps-api">Changing the slider value by keypress</a></li>
		<li><a href="#section-skipping">Skipping values on a slider</a></li>
		<li><a href="#section-toggle">Create a toggle</a></li>
		<li><a href="#section-soft-limits">Block the edges of a slider</a></li>
		<li><a href="#section-from-center">Connect to the center of a slider</a></li>
	</ul>
</section>

<section>
    <div class="notice">Can't find something? See the full <a href="/nouislider/reference/">options reference</a>.</div>
</section>

<?php include 'examples-content/values.php'; ?>
<?php include 'examples-content/formatting.php'; ?>
<?php include 'examples-content/colorpicker.php'; ?>
<?php include 'examples-content/styling.php'; ?>
<?php include 'examples-content/pips.php'; ?>
<?php include 'examples-content/dates.php'; ?>
<?php include 'examples-content/merging-tooltips.php'; ?>
<?php include 'examples-content/html5.php'; ?>
<?php include 'examples-content/non-linear.php'; ?>
<?php include 'examples-content/lock.php'; ?>
<?php include 'examples-content/click-pips.php'; ?>
<?php include 'examples-content/hiding-tooltips.php'; ?>
<?php include 'examples-content/colored-connect.php'; ?>
<?php include 'examples-content/steps-api.php'; ?>
<?php include 'examples-content/skipping.php'; ?>
<?php include 'examples-content/toggle.php'; ?>
<?php include 'examples-content/soft-limits.php'; ?>
<?php include 'examples-content/from-center.php'; ?>
